%define _default_patch_fuzz 1

Name:           udunits
Version:        1.12.9
Release:        %mkrel 5
Summary:        A library for manipulating units of physical quantities
License:        Freely distributable (BSD-like)
Group:          Sciences/Mathematics
URL:            http://www.unidata.ucar.edu/software/udunits/udunits-1/
Source0:        ftp://ftp.unidata.ucar.edu/pub/%{name}/%{name}-%{version}.tar.gz
Patch0:         %{name}-1.12.4-linuxfixes.patch
Patch1:         %{name}-1.12.4-64bit.patch
BuildRequires:  gcc-gfortran
BuildRequires:  gcc-c++
BuildRequires:  groff
BuildRequires:  perl-devel
BuildRequires:  bison

%description
The Unidata units utility, udunits, supports conversion of unit specifications 
between formatted and binary forms, arithmetic manipulation of unit 
specifications, and conversion of values between compatible scales of 
measurement. A unit is the amount by which a physical quantity is measured. For
example:

                  Physical Quantity   Possible Unit
                  _________________   _____________
                        time              weeks
                      distance         centimeters
                        power             watts

This utility works interactively and has two modes. In one mode, both an input 
and output unit specification are given, causing the utility to print the 
conversion between them. In the other mode, only an input unit specification is
given. This causes the utility to print the definition -- in standard units -- 
of the input unit.


%package devel
Group:          Development/Other
Summary:        Headers and libraries for %{name}
Requires:       %{name} = %{version}-%{release}

%description devel
This package contains the files needed for compiling programs using
the %{name} library.


%package -n perl-%{name}
Summary:        Perl module for %{name}
Group:          Development/Perl
Requires:       %{name}

%description -n perl-%{name}
A perl module for %{name}.


%prep
%setup -q
%patch0 -p1
# Yes, this is a dirty hack.
%ifarch x86_64 ppc64 sparc64
%patch1 -p1
%endif

%build
export CC=gcc
%ifarch x86_64
export CFLAGS="%{optflags} -fPIC"
export CXXFLAGS="%{optflags} -fPIC"
%endif
cd src/
export LD_MATH=-lm 
%configure

# Don't use %make, don't compil...
make all 

%install
cd src/
sed "s?/usr?%{buildroot}%{_prefix}?" Makefile > Makefile.install
make PREFIX=%{buildroot}%{_prefix} datadir=%{buildroot}%{sysconfdir} \
    sysconfigdir=%{buildroot}%{_sysconfdir} -f Makefile.install install


find %{buildroot} \( -name perllocal.pod -o -name .packlist \) -exec rm -v {} \;
rm -rf %{buildroot}%{_datadir}/man3f

# Nuke perm
find %{buildroot}%{perl_vendorlib} -type d -exec chmod 755 {} \;

# Don't ship static libraries
rm -f %{buildroot}%{_libdir}/*.a

%files
%doc src/{COPYRIGHT,README,RELEASE_NOTES,VERSION}
%{_bindir}/%{name}
%{_mandir}/man1/%{name}*
%config(noreplace) %{_sysconfdir}/%{name}.dat

%files devel
%{_includedir}/%{name}.h
%{_includedir}/%{name}.inc
%{_mandir}/man3*/%{name}*

%files -n perl-%{name}
%{perl_vendorarch}/*
%{_mandir}/man1/%{name}perl*


%changelog

* Sun Jan 22 2012 kamil <kamil> 1.12.9-5.mga2
+ Revision: 199376
- fix URL

* Sun Jan 22 2012 kamil <kamil> 1.12.9-4.mga2
+ Revision: 199357
- adapt package for Mageia
- imported package udunits


* Thu Jul 22 2010 Jérôme Quelin <jquelin@mandriva.org> 1.12.9-3mdv2011.0
+ Revision: 556782
- perl 5.12 rebuild

* Sun Sep 20 2009 Thierry Vignaud <tv@mandriva.org> 1.12.9-2mdv2010.0
+ Revision: 445605
- rebuild

* Sun Jan 04 2009 Olivier Thauvin <nanardon@mandriva.org> 1.12.9-1mdv2009.1
+ Revision: 324046
- brequires bison
- remove wrong comment now
- 1.12.9

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

* Wed Jul 30 2008 Thierry Vignaud <tv@mandriva.org> 1.12.4-5mdv2009.0
+ Revision: 255048
- rebuild
- fix description-line-too-long

* Mon Jan 21 2008 Thierry Vignaud <tv@mandriva.org> 1.12.4-3mdv2008.1
+ Revision: 155664
- rebuild for new perl

* Wed Jan 02 2008 Olivier Blin <oblin@mandriva.com> 1.12.4-2mdv2008.1
+ Revision: 140924
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request


* Wed Aug 09 2006 Olivier Thauvin <nanardon@mandriva.org>
+ 08/09/06 20:30:20 (55125)
- rebuild

* Wed Aug 09 2006 Olivier Thauvin <nanardon@mandriva.org>
+ 08/09/06 20:27:48 (55124)
Import udunits

* Thu Sep 29 2005 Olivier Thauvin <nanardon@mandriva.org> 1.12.4-1mdk
- From Philippe Weill <Philippe.Weill@aero.jussieu.fr>
  - Inital Mandriva spec

* Mon May 09 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.12.4-8
- remove hardcoded dist tags

* Fri May 06 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.12.4-7
- fix BuildRequires for the FC-3 spec (gcc-g77 vs gcc-gfortran)

* Fri Apr 22 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.12.4-6.fc4
- use dist tag

* Sat Apr 16 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.12.4-5
- x86_64 needs -fPIC

* Mon Apr 11 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.12.4-4
- use perl macros

* Mon Apr 11 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.12.4-3
- Corrected license
- Add BuildRequires: groff
- Add perl MODULE_COMPAT requires for perl-udunits
- Roll in fixes from Ed Hill's package
- Make -devel package

* Mon Apr 11 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.12.4-2
- minor spec cleanup

* Fri Mar 25 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.12.4-1
- inital package for Fedora Extras

